import { Button, Space, Modal, FormInstance } from "antd";
import { inject, observer } from "mobx-react";
import BTable from "@/components/b_table";
import { useEffect, useState } from "react";
import { Store } from "antd/lib/form/interface";
import React from "react";
import { columns, defaultConfig } from "./user_config";
import "./user.less";
import SimpleForm from "@/components/form/simple_form";

const User = (props: Store) => {
  const { usrStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const formRef = React.useRef<FormInstance>(null);
  const [userId, setId] = useState<Number | null>(null);
  const [record, setRecord] = useState<any>(null);

  // 获取列表数据
  useEffect(() => {
    usrStore.getlist();
  }, [usrStore]);

  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Button type="default" onClick={() => setIsModalOpen(true)}>
          添加用户
        </Button>
        <BTable
          store={usrStore}
          scroll={{ x: "max-content" }}
          columns={columns}
          dataSource={usrStore.list}
          editCallback={(record) => {
            setIsModalOpen(true);
            formRef.current?.setFieldsValue(record);
            setRecord(record);
            setId(record.id);
          }}
        />

        <Modal
          title={!userId ? "添加用户" : "编辑用户"}
          width={800}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          okText="确定"
          cancelText="取消"
          onCancel={() => {
            setId(null);
            setRecord(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formName={"user_form"}
            formRef={formRef}
            colProps={25}
            onFinish={() => {
              usrStore.add(formRef.current?.getFieldsValue())
            }}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formDatas={defaultConfig as any}
          ></SimpleForm>
        </Modal>
      </Space>
    </div>
  );
};

export default inject("usrStore")(observer(User));
